# HsioeFlask v0.0.1

` HsioeFlask(HF)` 致力打造一款模块级， 职责分明， 完全基于 `python` 的  `Web开发框架` 。 `HF` 将会提供常用的基础模块， 如 缓存， 队列， 定时任务， 异步任务， 数据库ORM.

> 本框架为了提现语言特效和动态语言的弊端， 会大量使用3.5 之后的特效，所以本框架仅支持 python 3.5 + 以上版本， 都2020年了， 环境配置应该是很容易的！

### 框架特点

- 模块化， 保证模块之间高内聚，低耦合
- 简便易用

### 开源地址

- 码云:  https://gitee.com/hsioe_david/hsioe-flask.git


### 框架安装

### 版本要求

### 框架设计架构